Module apply

Module apply 

Functions

apply_value
Apply callee to the already-evaluated args.
dispatch_if_async
If callee is an ^:async Clojure function and an async runtime is registered, spawn its body as a task and return a Value::Future.
type_tag_matches
Allocation-free check that val’s protocol dispatch tag equals tag.
type_tag_of
Return the canonical type tag for a value (used by protocol dispatch).