install_eval_context_guard

Function install_eval_context_guard 

pub fn install_eval_context_guard(
    globals: Arc<GlobalEnv>,
    ns: Arc<str>,
) -> EvalContextGuard
Like install_eval_context, but returns a guard that pops the context when dropped.

Used by the JIT-native dispatch seam: native code resolves globals and calls function values through rt_abi bridges that all require an eval context on the calling thread.