CompiledNsLoader

Type Alias CompiledNsLoader 

pub type CompiledNsLoader = Arc<dyn Fn(&Arc<GlobalEnv>) -> EvalResult<()> + Send + Sync>;
Loader callback for an AOT-compiled namespace (see GlobalEnv::compiled_ns_loaders). Given the global env, it loads the namespace by running its interpreted preamble and its compiled initializer.

Aliased Type

pub struct CompiledNsLoader { /* private fields */ }