Module loader

Module loader 

Namespace file loader: resolves require to source files and evaluates them.

Functions

load_ns
Find, load, and wire up the source file for spec.ns.
load_versioned_ns
Load spec.ns at commit, registering the result as the namespace "<spec.ns>@<commit>" in the global namespace table.