Module macros

Module macros 

Macro expansion pipeline.

Functions

macroexpand
Fully expand a form until the head is no longer a macro.
macroexpand_1
Expand a form one step. Returns the same form if it is not a macro call.
macroexpand_all
Recursively macro-expand all forms in a tree.
value_to_form
Convert a Value to a Form (inverse of form_to_value).