Syntax-quote (backtick) expansion.
Syntax-quote is evaluated directly to a Value, rather than being
expanded to intermediate AST and then evaluated.
Functions
- syntax_
quote - Expand a syntax-quoted form to a Value.
Syntax-quote (backtick) expansion.
Syntax-quote is evaluated directly to a Value, rather than being
expanded to intermediate AST and then evaluated.