Functions
- apply_
value - Apply
calleeto the already-evaluatedargs. - dispatch_
if_ async - If
calleeis an^:asyncClojure function and an async runtime is registered, spawn its body as a task and return aValue::Future. - type_
tag_ matches - Allocation-free check that
val’s protocol dispatch tag equalstag. - type_
tag_ of - Return the canonical type tag for a value (used by protocol dispatch).