Function application and the recur trampoline.
Structs
- Closure
Thunk - A Thunk that calls a zero-arg Clojure closure when forced.
Functions
- bind_
fn_ params - Bind function parameters in the current (top) frame.
- call_
cljrs_ fn - Tree-walking execution path (original implementation).
- dispatch_
method - Dispatch
(.method target args…)on an already-evaluated target. - eval_
alter_ var_ root - Execute
alter-var-rootwith already-evaluated args:[var, f, extra...]. - eval_
call - Evaluate a call expression
(func-form arg1 arg2 ...). - eval_
reset_ bang - Execute
reset!with already-evaluated args:[atom, new-val]. - eval_
send_ to_ agent - Execute
send/send-offwith already-evaluated args:[agent, f, extra...]. - eval_
swap_ bang - Execute
swap!with already-evaluated args:[atom, f, extra...]. - eval_
vary_ meta - Execute
vary-metawith already-evaluated args:[obj, f, extra...]. - eval_
volatile - Execute
volatile!with already-evaluated args:[init-val]. - eval_
vreset_ bang - Execute
vreset!with already-evaluated args:[volatile, new-val]. - eval_
vswap_ bang - Execute
vswap!with already-evaluated args:[volatile, f, extra...]. - eval_
with_ bindings_ star - Execute
with-bindings*with already-evaluated args:[bindings-map, f]. - handle_
make_ lazy_ seq - Handle
(make-lazy-seq f)— wraps a zero-arg fn in a lazy sequence. - make_
delay_ from_ fn - Wrap a zero-arg callable in a
Value::Delay. - make_
lazy_ seq_ from_ fn - Wrap a zero-arg callable value in a
Value::LazySeqwhoseforcecalls it. - resolve_
type_ tag - Resolve a type symbol from
extend-typeto a canonical tag. Canonical tags ARE the short names, so this just passes through. - select_
arity - Select the matching arity for the given argument count.