Macro expansion pipeline.
Functions
- macroexpand
- Fully expand a form until the head is no longer a macro.
- macroexpand_
1 - Expand a form one step. Returns the same form if it is not a macro call.
- macroexpand_
all - Recursively macro-expand all forms in a tree.
- value_
to_ form - Convert a
Valueto aForm(inverse ofform_to_value).