pub fn init(filter: Targets)Expand description
Install filter as the process’s global subscriber, formatting to stderr.
Idempotent in the sense that a second call (or a host that installed its own subscriber first) is ignored rather than panicking.